*___ Figure 9: Population and GDP weighted mean real house price indices, 14 countries ___

sort year iso
gen pop1=pop
replace pop1=. if hpreal==.
by year: egen poptot=sum(pop1)
gen weight2=pop1/poptot
gen hpreal_w2a=hpreal*weight2
by year: egen hpreal_w2b=sum(hpreal_w2a)
label var hpreal_w2b "Weighted Index - Population"

gen gdpus=gdp/xrusd // gdp in USD
replace gdpus=gdpus/1000 if iso=="AUS" & iso=="BEL" & iso=="CHE" & iso=="NLD" ///
	& iso=="NOR" & iso=="SWE" // convert in bn USD
replace gdpus=gdpus/1000000 if iso=="JPN" // convert in bn USD

gen gdpus1=gdpus
replace gdpus1=. if hpreal==.
by year: egen gdpustot=sum(gdpus1)
gen weight3=gdpus1/gdpustot
gen weight3a=weight3 if year==2008
sort ccode year
by ccode: egen weight3b=max(weight3a)
replace weight3=weight3b if year>=2008
sort year iso
gen hpreal_w3a=hpreal*weight3
by year: egen hpreal_w3b=sum(hpreal_w3a)
label var hpreal_w3b "Weighted Index - GDP"

scatter hpreal_w2b hpreal_mean year if year>=1870 & year<=2011 & iso=="USA", ///
	connect(i i)  xlabel(#14) scheme(s1color) /// 
	msize(small small) tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 ///
	1943 1944 1945, lc(ltbluishgray ) lw(vthick)) ///
	xtitle("") legend(size(small)) name(weight1,replace)   
scatter hpreal_w3b hpreal_mean year if year>=1870 & year<=2012 & iso=="USA", ///
	scheme(s1color)  /// 
	tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 1943 1944 1945, lc(ltbluishgray ) lw(vthick)) ///
	connect (i i)  msize(small small) xlabel(#14) ///
	xtitle("") legend(size(small)) name(weight2,replace)   
graph combine weight1 weight2, ///
	xsize(8) scheme(s1color)
	graph export ../tablesfigures/Fig9.pdf, replace
	
drop weight3 weight3a weight3b pop1 poptot weight2 hpreal_w2b hpreal_w2a ///
	gdpus1 gdpustot hpreal_w3a gdpus
	

*___ Figure 10: Area and GDP p.c. weighted mean real house price indices, 14 countries ___

sort year iso
set more off
gen gdppc1=rgdpbarro
replace gdppc1=. if hpreal==.
by year: egen gdppctot=sum(gdppc1)
gen weight4=gdppc1/gdppctot
sort year iso
gen hpreal_w4a=hpreal*weight4
by year: egen hpreal_w4b=sum(hpreal_w4a)
label var hpreal_w4b "Weighted Index - Income (GDP p.c.)"

sort year iso
set more off 
gen area1=area
replace area1=. if hpreal==.
by year: egen areatot=sum(area1) 
gen weight5=area1/areatot 
gen hpreal_w5a=hpreal*weight5 
by year: egen hpreal_w5b=sum(hpreal_w5a)
label var hpreal_w5b "Weighted Index - Area"

scatter hpreal_w4b hpreal_mean year if year>=1870 & year<=2012 & iso=="USA", ///
	scheme(s1color)  /// 
	tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 1943 1944 1945, lc(ltbluishgray ) lw(vthick)) ///
	connect (i i)  msize(small small) xlabel(#14) ///
	xtitle("") legend(size(small)) name(weight3,replace)   
scatter hpreal_w5b hpreal_mean year if year>=1870 & year<=2011 & iso=="AUS", ///
	connect(i i)  xlabel(#14) scheme(s1color) /// 
	msize(small small) tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 1943 1944 1945, lc(ltbluishgray ) lw(vthick)) ///
	xtitle("") legend(size(small)) name(weight4,replace)   
graph combine weight4 weight3, ///
	xsize(8) scheme(s1color)
	graph export ../tablesfigures/Fig10.pdf, replace
	
drop gdppc1 gdppctot weight4 hpreal_w4a hpreal_w4b area1 areatot hpreal_w5b ///
	hpreal_w5a weight5

*___ Figure 11: Mean of all available data, fixed samples ___

sort year iso

by year: egen hpreal_meanFS4=mean(hpreal) if iso=="AUS" | iso=="FRA" | ///
	iso=="NLD" | iso=="NOR"
label var hpreal_meanFS4 "4 Countries (Data since 1870)" 
	
by year: egen hpreal_meanFS5=mean(hpreal) if year>=1880 & iso=="AUS" | ///
	iso=="FRA" | iso=="NLD" | iso=="NOR" | iso=="DNK" | iso=="SWE" 
label var hpreal_meanFS5 "6 Countries (Data since 1880)" 
	
by year: egen hpreal_meanFS6=mean(hpreal) if year>=1905 & iso=="AUS" | ///
	iso=="FRA" | iso=="NLD" | iso=="NOR" | iso=="DNK" | iso=="SWE" ///
	| iso=="CHE" | iso=="USA" | iso=="FIN"
label var hpreal_meanFS6 "9 Countries (Data since 1905)"  
	
	
scatter hpreal_meanFS4 hpreal_meanFS5 hpreal_meanFS6 hpreal_mean year if ///
	year>=1870 & iso=="AUS", xlabel(#14) xtitle("") scheme(s1color) /// 
	msize(small small small small) tline(1914 1915 1916 1917 1918 1919 1939 ///
	1940 1941 1942 1943 1944 1945, lc(ltbluishgray ) lw(vthick)) /// 
	msymbol(o o o o) legend(size(small))    
	graph export ../tablesfigures/Fig11.pdf, replace
	
drop hpreal_meanFS4 hpreal_meanFS5 hpreal_meanFS6

capture cd ../data
save Workfile, replace
clear 
use NPLH_Decomposition
capture cd ../programs

*___ Figure 12: Figure 12: Imputed land prices - sensitivity analysis w.r.t. alpha, 14 countries ___

label var realimplp_all "Real Mean Imputed Land Price Index (alpha=0.5)"

scatter realimplp_all2 realimplp_all realimplp_all3   year if year>=1880 & ///
	year<=2012 & iso=="AUS", msize(small small small small small) xlabel(#13) ///
	xtitle("") scheme(s1color) tline(1914 1915 1916 1917 1918 1919 1939 1940 ///
	1941 1942 1943 1944 1945, lc(ltbluishgray ) lw(vthick)) ///
	leg(size(vsmall) cols(2))    
graph export ../tablesfigures/Fig12.pdf, replace


*___ Figure 13: Imputed land prices - sensitivity analysis w.r.t. technology, 14 countries ___

label var realimplp_all "Imputed land price - Cobb-Douglas"

scatter realimplp_all ILP_L year if year>=1881, ///
	xlabel(#14) xtitle("") tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 ///
	1943 1944 1945, lc(ltbluishgray) lw(vthick)) ///
	scheme(s1color) msize(small small)   
graph export ../tablesfigures/Fig13.pdf, replace

*___ Figure 14: Real house prices, 14 countries ___

capture cd ../data
clear 
use "Workfile"
capture cd ../programs

sort ccode year
by ccode: gen cpi_exp=(l1.dlcpi+l2.dlcpi+l3.dlcpi+l4.dlcpi+l5.dlcpi)/5
by ccode: gen cpi_exp2=100 if cpi_exp==. & cpi_exp[_n+1]~=.

forvalues i =1/17 {
    replace cpi_exp2=l1.cpi_exp2*(1+cpi_exp) if cpi_exp2==. & cpi_exp2[_n-1]~=. & ccode==`i'
    }
	
* gaps in BEL (1915-1919,1940-1944), DEU (1919-1923), JPN (1940-1947), correct
	
gen infl_BEL=lcpi-lcpi[_n-11] if year==1925 & iso=="BEL"
	replace infl_BEL=lcpi-lcpi[_n-11] if year==1950 & iso=="BEL"
	replace cpi_exp2=cpi_exp2[_n-11]*(1+infl_BEL) if iso=="BEL" & year==1925 
	replace cpi_exp2=. if iso=="BEL" & year>=1926 & year<=1940
	forvalues i =1/17 {
    replace cpi_exp2=l1.cpi_exp2*(1+cpi_exp) if cpi_exp2==. & cpi_exp2[_n-1]~=. & ccode==`i' 
    }

	replace cpi_exp2=cpi_exp2[_n-11]*(1+infl_BEL) if iso=="BEL" & year==1950
	replace cpi_exp2=. if iso=="BEL" & year>=1951
	forvalues i =1/17 {
    replace cpi_exp2=l1.cpi_exp2*(1+cpi_exp) if cpi_exp2==. & cpi_exp2[_n-1]~=. & ccode==`i' 
    }

	drop infl_BEL
	gen infl_JPN=lcpi-lcpi[_n-14] if year==1953 & iso=="JPN"
	replace cpi_exp2=cpi_exp2[_n-14]*(1+infl_JPN) if iso=="JPN" & year==1953
	replace cpi_exp2=. if iso=="JPN" & year>=1954
	forvalues i =1/17 {
    replace cpi_exp2=l1.cpi_exp2*(1+cpi_exp) if cpi_exp2==. & cpi_exp2[_n-1]~=. & ccode==`i' 
    }	
	
	drop infl_JPN
	gen infl_DEU=lcpi-lcpi[_n-11] if year==1929 & iso=="DEU"
	replace cpi_exp2=cpi_exp2[_n-11]*(1+infl_DEU) if iso=="DEU" & year==1929
	replace cpi_exp2=. if iso=="DEU" & year>=1930
	forvalues i =1/17 {
    replace cpi_exp2=l1.cpi_exp2*(1+cpi_exp) if cpi_exp2==. & cpi_exp2[_n-1]~=. & ccode==`i' 
    }	
	
	drop infl_DEU

sort iso year
gen base_cpiexp=cpi_exp2 if year==1990
by iso: egen base_cpiexp2=max(base_cpiexp)
by iso: gen cpi_exp3=cpi_exp2/base_cpiexp2*100
label var cpi_exp3 "Expected Inflation"
drop base_cpiexp cpi_exp2 base_cpiexp2 cpi_exp2	cpi_exp

replace cpi_exp3=cpi_exp3/10000000000 if iso=="DEU" & year<=1919
gen hpreal_exp=hpnom/cpi_exp3*100
sort year iso

label var hpreal_exp "Real House Prices (Expected Inflation)"
scatter  hpreal hpreal_exp year if year>=1870, ///
	by(iso) msymbol(o o) xlabel(#3) xtitle("") scheme(s1color) /// 
	msize(small small) tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 ///
	1943 1944 1945, lc(ltbluishgray ) lw(vthick)) legend(size(small))    
	graph export ../tablesfigures/Fig14.pdf, replace

drop cpi_exp3 hpreal_exp 

	
*___ Figure 15: Real construction costs, 14 countries ___

scatter ccreal year if year>=1870,  ///
	legend(size(vsmall)) scheme(s1color) by(iso) xtitle("") ytitle("") ///
	msize(small small) msymbol(o o) tline(1914 1915 1916 1917 1918 1919 1939 ///
	1940 1941 1942 1943 1944 1945, lc(ltbluishgray ) lw(vthick))   
	graph export ../tablesfigures/Fig15.pdf, replace	


*___ Figure 16: Real residential land prices, 6 countries ___ 

sort iso year
replace lpreal=lpnom/cpi*100 if lpnom~=.
gen CHEbase=lpreal if year==1975 & iso=="CHE" // rebase CHE to 1975=100
egen CHEbase2=max(CHEbase)
replace lpreal=lpreal/CHEbase2*100 if iso=="CHE"
drop CHEbase CHEbase2
replace lpreal=hpreal if iso=="JPN"

label var lpreal "Real Residential Land Price Index"
scatter lpreal year if year>=1880 & iso=="AUS" | ///
	iso=="BEL" | iso=="CHE" | iso=="GBR" | iso=="USA" | ///
	iso=="JPN",  ///
	legend(size(vsmall)) scheme(s1color) msize(small )  by(iso) ytitle("") ///
	xtitle("") tline(1914 1915 1916 1917 1918 1919 1939 1940 1941 1942 1943 ///
	1944 1945, lc(ltbluishgray ) lw(thick))   
	graph export ../tablesfigures/Fig16.pdf, replace

*____ Summary Statistics for Table 4 ___

* full country sample
tabstat dlhpnom dlcpi dlrgdpbarro if war~=1 & year<=2012, statistics(n mean sd)
tabstat dlhpnom dlcpi dlrgdpbarro if pre45==1 & war~=1 , statistics(n mean sd)
tabstat dlhpnom dlcpi dlrgdpbarro if post45==1 & war~=1 & year<=2012, statistics(n mean sd)

* by country
by iso: tabstat dlhpnom dlcpi dlrgdpbarro if war~=1 & year<=2012, statistics(n mean sd)
by iso: tabstat dlhpnom dlcpi dlrgdpbarro if pre45==1 & war~=1, statistics(n mean sd)
by iso: tabstat dlhpnom dlcpi dlrgdpbarro if post45==1 & war~=1 & year<=2012, statistics(n mean sd)


	
	

